@@ -2,8 +2,8 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-package Authen::SASL;
-$Authen::SASL::VERSION = '2.1800';
+package Authen::SASL 2.2000;
+
 use strict;
 use warnings;
 use vars qw(@Plugins);
