@@ -2,11 +2,15 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-package Authen::SASL::CRAM_MD5;
-$Authen::SASL::CRAM_MD5::VERSION = '2.1800';
+package Authen::SASL::CRAM_MD5 2.2000;
+
 use strict;
 use warnings;
 
+warnings::warnif(
+    'deprecated',
+    'The CRAM-MD5 SASL mechanism is effectively deprecated by RFC8314 and should no longer be used'
+    );
 
 sub new {
   shift;
