@@ -5,14 +5,20 @@
 
 # See http://www.ietf.org/rfc/rfc2831.txt for details
 
-package Authen::SASL::Perl::DIGEST_MD5;
-$Authen::SASL::Perl::DIGEST_MD5::VERSION = '2.1800';
+package Authen::SASL::Perl::DIGEST_MD5 2.2000;
+
 use strict;
 use warnings;
 use vars qw(@ISA $CNONCE $NONCE);
+use Crypt::URandom qw(urandom);
 use Digest::MD5 qw(md5_hex md5);
 use Digest::HMAC_MD5 qw(hmac_md5);
 
+warnings::warnif(
+    'deprecated',
+    'The DIGEST-MD5 SASL mechanism is deprecated by RFC6331 and should no longer be used'
+    );
+
 # TODO: complete qop support in server, should be configurable
 
 @ISA = qw(Authen::SASL::Perl);
@@ -201,7 +207,7 @@ sub server_start {
 
   $self->{need_step} = 1;
   $self->{error}     = undef;
-  $self->{nonce}     = md5_hex($NONCE || join (":", $$, time, rand));
+  $self->{nonce}     = $NONCE ? md5_hex($NONCE) : unpack('H32',urandom(16));
 
   $self->init_sec_layer;
 
@@ -260,7 +266,7 @@ sub client_step {   # $self, $server_sasl_credentials
 
   my %response = (
     nonce        => $sparams{'nonce'},
-    cnonce       => md5_hex($CNONCE || join (":", $$, time, rand)),
+    cnonce       => $CNONCE ? md5_hex($CNONCE) : unpack('H32',urandom(16)),
     'digest-uri' => $self->service . '/' . $self->host,
     # calc how often the server nonce has been seen; server expects "00000001"
     nc           => sprintf("%08d",     ++$self->{nonce_counts}{$sparams{'nonce'}}),
@@ -746,11 +752,11 @@ __END__
 
 =head1 NAME
 
-Authen::SASL::Perl::DIGEST_MD5 - Digest MD5 Authentication class
+Authen::SASL::Perl::DIGEST_MD5 - (DEPRECATED) Digest MD5 Authentication class
 
 =head1 VERSION
 
-version 2.1800
+version 2.2000
 
 =head1 SYNOPSIS
 
@@ -770,6 +776,10 @@ version 2.1800
 This method implements the client and server parts of the DIGEST-MD5 SASL
 algorithm, as described in RFC 2831.
 
+Please note that this mechanism has been moved to the "OBSOLETE" section of
+the L<mechanism registry|https://www.iana.org/assignments/sasl-mechanisms/sasl-mechanisms.xhtml>
+as per L<RFC6331|https://www.rfc-editor.org/rfc/rfc6331.html>.
+
 =head2 CALLBACK
 
 The callbacks used are:
