@@ -3,8 +3,8 @@
 # is free software; you can redistribute it and/or modify it under the
 # same terms as Perl itself.
 
-package Authen::SASL::Perl::EXTERNAL;
-$Authen::SASL::Perl::EXTERNAL::VERSION = '2.1700';
+package Authen::SASL::Perl::EXTERNAL 2.2000;
+
 use strict;
 use warnings;
 use vars qw(@ISA);
@@ -45,7 +45,7 @@ Authen::SASL::Perl::EXTERNAL - External Authentication class
 
 =head1 VERSION
 
-version 2.1700
+version 2.2000
 
 =head1 SYNOPSIS
 
