@@ -4,9 +4,10 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-package Authen::SASL::Perl::OAUTHBEARER 2.1900;
+package Authen::SASL::Perl::OAUTHBEARER 2.2000;
 
 use strict;
+use warnings;
 use vars qw(@ISA);
 use JSON::PP;
 
@@ -38,13 +39,24 @@ sub client_start {
     # * gs2-authzid `a=" {User} "`
     #
     # The second part are key value pairs containing host, port and auth as
-    # described in RFC7628.
+    # described in RFC7628. Host and port are optional and can be omitted.
     #
     # https://datatracker.ietf.org/doc/html/rfc5801
     # https://datatracker.ietf.org/doc/html/rfc7628
     my $username = $self->_call('user');
+    my $host     = $self->_call('host');
+    my $port     = $self->_call('port');
     my $token    = $self->_call('pass'); # OAuth 2.0 access token
-    my $auth_string = "n,a=$username,\001auth=Bearer $token\001\001";
+    my $auth_string;
+    if (defined $host && defined $port) {
+      $auth_string = "n,a=$username,\001host=$host\001port=$port\001auth=Bearer $token\001\001";
+    } elsif (defined $host) {
+      $auth_string = "n,a=$username,\001host=$host\001auth=Bearer $token\001\001";
+    } elsif (defined $port) {
+      $auth_string = "n,a=$username,\001port=$port\001auth=Bearer $token\001\001";
+    } else {
+      $auth_string = "n,a=$username,\001auth=Bearer $token\001\001";
+    }
 
     return $auth_string;
 }
@@ -69,7 +81,7 @@ Authen::SASL::Perl::OAUTHBEARER - OAUTHBEARER Authentication class
 
 =head1 VERSION
 
-version 2.1900
+version 2.2000
 
 =head1 SYNOPSIS
 
@@ -79,6 +91,8 @@ version 2.1900
     mechanism => 'OAUTHBEARER',
     callback  => {
       user => $user,
+      host => $hostname, #optional
+      port => $port, #optional
       pass => $access_token
     },
   );
@@ -100,6 +114,14 @@ The callbacks used are:
 
 The username to be used for authentication.
 
+=item host
+
+The hostname to which the client will connect to. It is optional and can be omitted.
+
+=item port
+
+The destination port that the client will connect to. It should be a decimal positive integer string without leading zeros. It is optional and can be omitted.
+
 =item pass
 
 The OAuth 2.0 access token to be used for authentication.
