@@ -2,12 +2,12 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-package Authen::SASL::Perl::PLAIN;
+package Authen::SASL::Perl::PLAIN 2.2000;
 
 use strict;
-use vars qw($VERSION @ISA);
+use warnings;
+use vars qw(@ISA);
 
-$VERSION = "2.14";
 @ISA	 = qw(Authen::SASL::Perl);
 
 my %secflags = (
@@ -61,11 +61,11 @@ sub server_start {
       my $result = shift;
       unless ($result) {
         $self->set_error($error);
-        $user_cb->();
       }
       else {
         $self->set_success;
       }
+      $user_cb->();
     };
     $checkpass->($self => { %parts } => $cb );
     return;
@@ -102,6 +102,10 @@ __END__
 
 Authen::SASL::Perl::PLAIN - Plain Login Authentication class
 
+=head1 VERSION
+
+version 2.2000
+
 =head1 SYNOPSIS
 
   use Authen::SASL qw(Perl);
@@ -143,7 +147,7 @@ The user's password to be used for authentication.
 
 =head3 Server
 
-=over4
+=over 4
 
 =item checkpass(username, password, realm)
 
